From 450566dc9ac1c79d7feed2098fb75d2f81f97266 Mon Sep 17 00:00:00 2001
From: Matt Oliver <protogonoi@gmail.com>
Date: Thu, 13 Mar 2014 22:19:37 +1100
Subject: [PATCH 3/3] Fix x264cli compatibility with msvc.

---
 filters/video/cache.c       |  2 ++
 filters/video/fix_vfr_pts.c |  2 ++
 input/avs.c                 | 11 +++++++++--
 input/input.c               |  4 ++++
 input/y4m.c                 |  4 +++-
 output/flv_bytestream.c     |  3 ++-
 output/matroska.c           |  2 ++
 7 files changed, 24 insertions(+), 4 deletions(-)

diff --git a/filters/video/cache.c b/filters/video/cache.c
index 6de005f..e960b5f 100644
--- a/filters/video/cache.c
+++ b/filters/video/cache.c
@@ -47,7 +47,9 @@ static int init( hnd_t *handle, cli_vid_filter_t *filter, video_info_t *info, x2
     intptr_t size = (intptr_t)opt_string;
     /* upon a <= 0 cache request, do nothing */
     if( size <= 0 )
+    {
         return 0;
+    }
     cache_hnd_t *h = calloc( 1, sizeof(cache_hnd_t) );
     if( !h )
         return -1;
diff --git a/filters/video/fix_vfr_pts.c b/filters/video/fix_vfr_pts.c
index 9bf870b..24801ec 100644
--- a/filters/video/fix_vfr_pts.c
+++ b/filters/video/fix_vfr_pts.c
@@ -52,7 +52,9 @@ static int init( hnd_t *handle, cli_vid_filter_t *filter, video_info_t *info, x2
 {
     /* if the input is not vfr, we don't do anything */
     if( !info->vfr )
+    {
         return 0;
+    }
     fix_vfr_pts_hnd_t *h = calloc( 1, sizeof(fix_vfr_pts_hnd_t) );
     if( !h )
         return -1;
diff --git a/input/avs.c b/input/avs.c
index 918978f..c4e14d1 100644
--- a/input/avs.c
+++ b/input/avs.c
@@ -298,7 +298,10 @@ static int open_file( char *psz_filename, hnd_t *p_handle, video_info_t *info, c
             opt->input_range = opt->output_range;
         }
         const char *arg_name[] = { NULL, "interlaced", "matrix" };
-        AVS_Value arg_arr[] = { res, avs_new_value_bool( info->interlaced ), avs_new_value_string( matrix ) };
+        AVS_Value arg_arr[3];
+        arg_arr[0] = res;
+        arg_arr[1] = avs_new_value_bool( info->interlaced );
+        arg_arr[2] = avs_new_value_string( matrix );
         AVS_Value res2 = h->func.avs_invoke( h->env, conv_func, avs_new_value_array( arg_arr, arg_count ), arg_name );
         FAIL_IF_ERROR( avs_is_error( res2 ), "couldn't convert input clip to %s\n", csp )
         res = update_clip( h, &vi, res2, res );
@@ -308,7 +311,9 @@ static int open_file( char *psz_filename, hnd_t *p_handle, video_info_t *info, c
     {
         const char *levels = opt->output_range ? "TV->PC" : "PC->TV";
         x264_cli_log( "avs", X264_LOG_WARNING, "performing %s conversion\n", levels );
-        AVS_Value arg_arr[] = { res, avs_new_value_string( levels ) };
+        AVS_Value arg_arr[2];;
+        arg_arr[0] = res;
+        arg_arr[1] = avs_new_value_string( levels );
         const char *arg_name[] = { NULL, "levels" };
         AVS_Value res2 = h->func.avs_invoke( h->env, "ColorYUV", avs_new_value_array( arg_arr, 2 ), arg_name );
         FAIL_IF_ERROR( avs_is_error( res2 ), "couldn't convert range: %s\n", avs_as_error( res2 ) )
@@ -374,7 +379,9 @@ static int read_frame( cli_pic_t *pic, hnd_t handle, int i_frame )
     static const int plane[3] = { AVS_PLANAR_Y, AVS_PLANAR_U, AVS_PLANAR_V };
     avs_hnd_t *h = handle;
     if( i_frame >= h->num_frames )
+    {
         return -1;
+    }
     AVS_VideoFrame *frm = pic->opaque = h->func.avs_get_frame( h->clip, i_frame );
     const char *err = h->func.avs_clip_get_error( h->clip );
     FAIL_IF_ERROR( err, "%s occurred while reading frame %d\n", err, i_frame )
diff --git a/input/input.c b/input/input.c
index c6bb5ac..26ec55b 100644
--- a/input/input.c
+++ b/input/input.c
@@ -57,7 +57,9 @@ uint64_t x264_cli_pic_plane_size( int csp, int width, int height, int plane )
 {
     int csp_mask = csp & X264_CSP_MASK;
     if( x264_cli_csp_is_invalid( csp ) || plane < 0 || plane >= x264_cli_csps[csp_mask].planes )
+    {
         return 0;
+    }
     uint64_t size = (uint64_t)width * height;
     size *= x264_cli_csps[csp_mask].width[plane] * x264_cli_csps[csp_mask].height[plane];
     size *= x264_cli_csp_depth_factor( csp );
@@ -67,7 +69,9 @@ uint64_t x264_cli_pic_plane_size( int csp, int width, int height, int plane )
 uint64_t x264_cli_pic_size( int csp, int width, int height )
 {
     if( x264_cli_csp_is_invalid( csp ) )
+    {
         return 0;
+    }
     uint64_t size = 0;
     int csp_mask = csp & X264_CSP_MASK;
     for( int i = 0; i < x264_cli_csps[csp_mask].planes; i++ )
diff --git a/input/y4m.c b/input/y4m.c
index 5597c43..d267bdb 100644
--- a/input/y4m.c
+++ b/input/y4m.c
@@ -197,9 +197,11 @@ static int open_file( char *psz_filename, hnd_t *p_handle, video_info_t *info, c
     h->frame_size     = h->frame_header_len;
 
     if( h->bit_depth > 8 )
+    {
         info->csp |= X264_CSP_HIGH_DEPTH;
+    }
 
-    const x264_cli_csp_t *csp = x264_cli_get_csp( info->csp );
+    x264_cli_csp_t *csp = x264_cli_get_csp( info->csp );
 
     for( i = 0; i < csp->planes; i++ )
     {
diff --git a/output/flv_bytestream.c b/output/flv_bytestream.c
index 2e7e861..4cefad8 100644
--- a/output/flv_bytestream.c
+++ b/output/flv_bytestream.c
@@ -28,7 +28,8 @@
 
 uint64_t flv_dbl2int( double value )
 {
-    return (union {double f; uint64_t i;}){value}.i;
+    union { double f; uint64_t i; } ulld = { value };
+    return ulld.i;
 }
 
 /* Put functions  */
diff --git a/output/matroska.c b/output/matroska.c
index baa0f1c..1cc574f 100644
--- a/output/matroska.c
+++ b/output/matroska.c
@@ -179,7 +179,9 @@ static int write_frame( hnd_t handle, uint8_t *p_nalu, int i_size, x264_picture_
     }
 
     if( mk_add_frame_data( p_mkv->w, p_nalu, i_size ) < 0 )
+    {
         return -1;
+    }
 
     int64_t i_stamp = (int64_t)((p_picture->i_pts * 1e9 * p_mkv->i_timebase_num / p_mkv->i_timebase_den) + 0.5);
 
-- 
1.8.4.msysgit.0

